#!/bin/bash
#
# FLVGET Plugin for "FunnyHub" version 1.0
# http://www.funnyhub.com/
#
# This plugin is released under GPL free license.
#
# Pablo Chinea <khertz@gmail.com>
#################################################

if [[ $1 == '-q' ]]
then
	echo "FLVGET_PLUGIN|FunnyHub|funnyhub.com"
	exit 0
fi

filename=$(echo "$1" | sed -e 's/^.*\/\(.*\)html$/\1flv/')
url="http://media.funnyhub.com/videos/$filename"

echo "$url|$filename"
