#!/bin/bash
#
# FLVGET Plugin for "theYNC.com" version 1.0
# http://www.theync.com/
#
# This plugin is released under GPL free license.
#
# Pablo Chinea <khertz@gmail.com>
#################################################

if [[ $1 == '-q' ]]
then
	echo "FLVGET_PLUGIN|theYNC.com|theync.com"
	exit 0
fi

url=$(echo "$1" | sed -e 's/m\//m\/video\//' -e 's/shtml/wmv/')
filename=$(echo "$url" | sed -e 's/.*\/\(.*\)$/\1/')

echo "$url|$filename"
