#!/bin/bash
#
# FLVGET Plugin for "MediaLunchobox" version 1.1
# http://www.medialunchbox.com/
#
# This plugin is released under GPL free license.
#
# Pablo Chinea <khertz@gmail.com>
#################################################

if [[ $1 == '-q' ]]
then
	echo "FLVGET_PLUGIN|MediaLunchobox|medialunchbox.com"
	exit 0
fi

id=$(echo "$1" | sed -e 's/^.*\/\([0-9]*\)\..*$/\1/')
url="http://www.medialunchbox.com/videos/$id.wmv"
filename=$(echo "$1" | cut -d'.' -f5).wmv

echo "$url|$filename"
