#!/bin/bash
#
# FLVGET Plugin for "Wrzuta" version 1.0
# http://www.wrzuta.pl/
#
# This plugin is released under GPL free license.
#
# Pablo Chinea <khertz@gmail.com>
#################################################

if [[ $1 == '-q' ]]
then
	echo "FLVGET_PLUGIN|Wrzuta|wrzuta.pl"
	exit 0
fi

url=$(echo "$1" | sed -e 's/film/vid\/file/')
filename=$(echo "$1" | cut -d'/' -f6).flv

echo "$url|$filename"
