#!/bin/bash
#
# FLVGET Plugin for "ExtremeVideos" version 1.1
# http://www.extremvideos.com/
#
# This plugin is released under GPL free license.
#
# Pablo Chinea <khertz@gmail.com>
#################################################

if [[ $1 == '-q' ]]
then
	echo "FLVGET_PLUGIN|ExtremeVideos|extremevideos.org"
	exit 0
fi

url="$(wget -q "$1" -O - | grep embed | cut -d'"' -f2)"
filename=$(echo "$url" | sed -e 's/.*\/\(.*\)$/\1/')

echo "$url|$filename"
