#!/bin/bash
#
# FLVGET Plugin for "aBum.com" version 1.1
# http://www.abum.com/
#
# This plugin is released under GPL free license.
#
# Pablo Chinea <khertz@gmail.com>
#################################################

if [[ $1 == '-q' ]]
then
	echo "FLVGET_PLUGIN|aBum.com|abum.com"
	exit 0
fi

id=$(echo "$1" | sed -e 's/.*\/\([0-9]*\)\/.*/\1/')
url="http://media.abum.com/video/src/$id.flv"
filename="$id.flv"

echo "$url|$filename"
