#!/bin/bash
#
# FLVGET Plugin for "Zappinternet" version 1.0
# http://www.zappinternet.com/
#
# This plugin is released under GPL free license.
#
# Pablo Chinea <khertz@gmail.com>
#################################################

if [[ $1 == '-q' ]]
then
	echo "FLVGET_PLUGIN|Zappinternet|zappinternet.com"
	exit 0
fi

id=$(echo "$1" | cut -d'/' -f5)
url="http://videos.zappinternet.com/videos/${id:0:1}/$id.flv"
filename=$(echo "$url" | cut -d'/' -f6)

echo "$url|$filename"

