#!/bin/bash
#
# FLVGET Plugin for "LemonZoo" version 1.1
# http://www.lemonzoo.com/
#
# This plugin is released under GPL free license.
#
# Pablo Chinea <khertz@gmail.com>
#################################################

if [[ $1 == '-q' ]]
then
	echo "FLVGET_PLUGIN|LemonZoo|lemonzoo.com"
	exit 0
fi

url="http://www.lemonzoo.com/mediafiles/flash8/$(echo $1 | sed -e 's/^.*\/\(.*\)\/.*$/\1/').flv"
filename=$(echo $1 | sed -e 's/^.*\/\(.*\).html$/\1.flv/')

echo "$url|$filename"
