#!/bin/bash
#
# FLVGET Plugin for "Daily Haha" version 1.0
# http://www.dailyhaha.com/
#
# This plugin is released under GPL free license.
#
# Pablo Chinea <khertz@gmail.com>
#################################################

if [[ $1 == '-q' ]]
then
	echo "FLVGET_PLUGIN|Daily Haha|dailyhaha.com/_vids"
	exit 0
fi

url=$(echo $1 | sed -e 's/htm$/wmv/')
filename=$(echo "$url" | sed -e 's/.*\/\(.*\)$/\1/')

echo "$url|$filename"
