#!/bin/bash
#
# FLVGET Plugin for "iFilm" version 1.1
# http://www.ifilm.com/
#
# This plugin is released under GPL free license.
#
# Pablo Chinea <khertz@gmail.com>
#################################################

if [[ $1 == '-q' ]]
then
	echo "FLVGET_PLUGIN|iFilm|ifilm.com"
	exit 0
fi

url=$(wget -q "$1" -O - | grep "var jstr" | tr '*' '\n' | grep -A 2 "^url$" | tail -1 | cut -d'?' -f1)
filename=$(echo "$url" | sed -e 's/.*\/\(.*\)$/\1/')

echo "$url|$filename"
