#!/bin/bash
#
# FLVGET Plugin for "Revver.com" version 1.0
# http://www.revver.com/
#
# This plugin is released under GPL free license.
#
# Pablo Chinea <khertz@gmail.com>
#################################################

if [[ $1 == '-q' ]]
then
	echo "FLVGET_PLUGIN|Revver.com|revver.com"
	exit 0
fi

id=$(echo "$1" | sed -e 's/[^[:digit:]]//g')
url="http://media.revver.com/broadcast/$id/video.mov"
filename="$id.mov"

echo "$url|$filename"

